==> girder-slicer-cli-web-1.0.1.dev15.zip: girder-slicer-cli-web-1.0.1.dev15/slicer_cli_web/web_client/parser/param.js <==
import $ from 'jquery';
import _ from 'underscore';

import widget from './widget';
import convert from './convert';
import defaultValue from './defaultValue';
import constraints from './constraints';

/**
 * Parse a parameter spec.
 * @param {XML} param The parameter spec
 * @returns {object}
 */
export default function param(paramTag, opts = {}) {
    const $param = $(paramTag);
    let type = widget(paramTag);
    let values = {};
    let channel = $param.find('channel');
    const id = $param.find('name').text() || $param.find('longflag').text();
    const extra = {};

    if (channel.length > 0) {
        channel = channel.text();
    } else {
        channel = 'input';
    }

    if ((type === 'file' || type === 'image') && channel === 'output') {
        type = 'new-file';
        extra.extensions = $param.attr('fileExtensions');
        extra.reference = $param.attr('reference');
        extra.required = $param.find('index').text().length > 0;
    } else if (channel === 'output') {
        opts.output = true;
        opts.params = _.extend(opts.params || {}, {
            [id]: type
        });
        return null;
    }

    if (!type) {
        console.warn('Unhandled parameter type "' + paramTag.tagName + '"'); // eslint-disable-line no-console
    }

    if (type === 'string-enumeration' || type === 'number-enumeration') {
        values = {
            values: _.map($param.find('element'), (el) => {
                return convert(type, $(el).text());
            })
        };
    }

    return _.extend(
        {
            type: type,
            slicerType: paramTag.tagName,
            title: $param.find('label').text(),
            description: $param.find('description').text(),
            channel,
            id
        },
        values,
        defaultValue(type, $param.find('default')),
        constraints(type, $param.find('constraints').get(0)),
        extra
    );
}

==> girder-slicer-cli-web-1.1.1.zip: girder-slicer-cli-web-1.1.1/slicer_cli_web/web_client/parser/param.js <==
import $ from 'jquery';
import _ from 'underscore';

import widget from './widget';
import convert from './convert';
import defaultValue from './defaultValue';
import constraints from './constraints';

/**
 * Parse a parameter spec.
 * @param {XML} param The parameter spec
 * @returns {object}
 */
export default function param(paramTag, opts = {}) {
    const $param = $(paramTag);
    let type = widget(paramTag);
    let values = {};
    let channel = $param.find('channel');
    const id = $param.find('name').text() || $param.find('longflag').text();
    const extra = {};

    if (channel.length > 0) {
        channel = channel.text();
    } else {
        channel = 'input';
    }

    if ((type === 'file' || type === 'image') && channel === 'output') {
        type = 'new-file';
        extra.extensions = $param.attr('fileExtensions');
        extra.reference = $param.attr('reference');
        extra.required = $param.find('index').text().length > 0;
    } else if (channel === 'output') {
        opts.output = true;
        opts.params = _.extend(opts.params || {}, {
            [id]: type
        });
        return null;
    } else if (channel === 'input' && ['image', 'file', 'item', 'directory'].includes(type)) {
        extra.defaultNameMatch = $param.attr('defaultNameMatch');
        extra.defaultPathMatch = $param.attr('defaultPathMatch');
    }

    if (!type) {
        console.warn('Unhandled parameter type "' + paramTag.tagName + '"'); // eslint-disable-line no-console
    }

    if (type === 'string-enumeration' || type === 'number-enumeration') {
        values = {
            values: _.map($param.find('element'), (el) => {
                return convert(type, $(el).text());
            })
        };
    }

    return _.extend(
        {
            type: type,
            slicerType: paramTag.tagName,
            title: $param.find('label').text(),
            description: $param.find('description').text(),
            channel,
            id
        },
        values,
        defaultValue(type, $param.find('default')),
        constraints(type, $param.find('constraints').get(0)),
        extra
    );
}
